'use strict';

Object.defineProperty(exports, Symbol.toStringTag, { value: 'Module' });

const qwik = require('@builder.io/qwik');
const types = require('./types.qwik.cjs');

const sizeClasses = {
  [types.SfProgressSize.xs]: "h-4 w-4 ring-2",
  [types.SfProgressSize.sm]: "h-5 w-5 ring-2",
  [types.SfProgressSize.base]: "h-6 w-6 ring-2",
  [types.SfProgressSize.lg]: "h-8 w-8 ring-2",
  [types.SfProgressSize.xl]: "h-10 w-10 ring-2",
  [types.SfProgressSize["2xl"]]: "h-14 w-14 ring-[3px]",
  [types.SfProgressSize["3xl"]]: "h-24 w-24 ring-4",
  [types.SfProgressSize["4xl"]]: "h-48 w-48 ring-8"
};
const strokeSizeClass = {
  [types.SfProgressSize.xs]: "stroke-[10px]",
  [types.SfProgressSize.sm]: "stroke-[8px]",
  [types.SfProgressSize.base]: "stroke-[6px]",
  [types.SfProgressSize.lg]: "stroke-[4px]",
  [types.SfProgressSize.xl]: "stroke-[3px]",
  [types.SfProgressSize["2xl"]]: "stroke-[3px]",
  [types.SfProgressSize["3xl"]]: "stroke-2",
  [types.SfProgressSize["4xl"]]: "stroke-2"
};
const SfProgressCircular = /* @__PURE__ */ qwik.componentQrl(/* @__PURE__ */ qwik.inlinedQrl(({ value = 0, size = types.SfProgressSize.base, ariaLabel = "Progress element", class: _class, ...attributes }) => {
  const strokeDasharray = `${value / 100 * 151}, 150`;
  return /* @__PURE__ */ qwik._jsxS("svg", {
    "aria-label": ariaLabel,
    "aria-valuenow": value,
    class: `inline-block ring-inset ring-neutral-300 text-primary-700 rounded-full transition-[stroke-dasharray] ease-in-out duration-500 text-sm 
          ${sizeClasses[size]} 
          ${_class}`,
    "stroke-dasharray": strokeDasharray,
    ...attributes,
    children: [
      /* @__PURE__ */ qwik._jsxQ("circle", {
        class: `origin-bottom-right -rotate-90 stroke-current fill-none ${strokeSizeClass[size]}`
      }, {
        cx: "50",
        cy: "50",
        r: "24"
      }, null, 3, null),
      /* @__PURE__ */ qwik._jsxC(qwik.Slot, null, 3, "9g_0")
    ]
  }, {
    "aria-valuemax": 100,
    "aria-valuemin": 0,
    "data-testid": "progress",
    role: "progressbar",
    viewBox: "25 25 50 50"
  }, 0, "9g_1");
}, "SfProgressCircular_component_n11VdTMU0TM"));

exports.SfProgressCircular = SfProgressCircular;
exports._auto_sizeClasses = sizeClasses;
exports._auto_strokeSizeClass = strokeSizeClass;
